@@ -1,7 +1,9 @@
 from . import datatools
 from . import fmn_plottools
+from . import fmn_datatools_v2
 
 __all__ = [
     'datatools',
-    'fmn_plottools'
+    'fmn_plottools',
+    'fmn_datatools_v2'
 ]
